PageSourceSearch

https://www.fredrikstadfk.no/om-klubben/bli-medlem

html fredrikstadfk.no collected 2026-10-02 12:21:35 UTC 68,978 bytes, 1,133 lines download raw bytes

1<!DOCTYPE html>
2<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="nb" lang="nb" prefix="og:https://ogp.me/ns">
3<head>
3<script id="Cookiebot" src="https://consent.cookiebot.com/uc.js" data-cbid="6ec37fe1-0bdc-4bd0-9faf-c539a2f10ab0" data-blockingmode="auto" type="text/javascript"></script>
3<link rel="preconnect" href="https://cdn.usefathom.com">
4    <meta charset="utf-8" />
5    <meta name="viewport" content="width=device-width, initial-scale=1.0">
6    
7    <meta http-equiv="content-language" content="nb-no">
8
9    <title>Bli medlem / Fredrikstad</title>
10    <link rel="home" href="https://www.fredrikstadfk.no/" />
11    <!-- Gotham XNarrow -->
12
13    <link rel="stylesheet" type="text/css" href="https://cloud.typography.com/6417356/6804032/css/fonts.css" />
14    <link rel="manifest" href="/manifest.json">
15
16    <!--<link rel="stylesheet" type="text/css" href="/css/.css"/>-->
17    <link rel="stylesheet" type="text/css" href="/_/asset/no.seeds.app.football:0000019ff17deeb0/compiled/css/ffk.css"/>
18    <link rel="stylesheet" type="text/css" href="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/compiled/css/seeds.css"/>
19    <link rel="stylesheet" type="text/css" href="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/css/jquery-ui.css"/>
20    
20<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/js/jquery.js"></script>
20
21    
21<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/js/jquery-ui.js"></script>
21
22    
22<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/js/jquery.cookie.js"></script>
22
23
24    
24<script src="https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.29.1/moment.min.js" integrity="sha512-qTXRIMyZIFb8iQcfjXWCO8+M5Tbc38Qi5WzdPOYZHIlZpzBHG3L3by84BBBOiRGiEb7KKtAOAs5qYdUiZiQNNQ==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
24
25    
25<script src="https://cdnjs.cloudflare.com/ajax/libs/moment-timezone/0.5.33/moment-timezone-with-data.min.js" integrity="sha512-rjmacQUGnwQ4OAAt3MoAmWDQIuswESNZwYcKC8nmdCIxAVkRC/Lk2ta2CWGgCZyS+FfBWPgaO01LvgwU/BX50Q==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
25
26
27    
27<script async src="https://securepubads.g.doubleclick.net/tag/js/gpt.js"></script>
27
28
29    
29<script type="text/javascript">
30        var redirectSession = sessionStorage.getItem('redirectSession');
31        var urlParams = new URLSearchParams(window.location.search);
32
33        if (redirectSession) {
34            sessionStorage.removeItem('redirectSession');
35            window.location.href = redirectSession;
36        }
37    </script>
37
38    <!-- ------------ smartApp Banner ------------------------------------- -->
39    
40    <!-- ------------------------------------------------------------------ -->
41
42	
43
44<style>
45#CybotCookiebotDialog a,
46#CybotCookiebotDialog a:hover,
47#CybotCookiebotDialog a:after
48{	
49  background-color: transparent;
50  border-bottom: none !important;
51}
52
53#CybotCookiebotDialog img{
54	width: auto !important;
55}
56</style><style>
57                        .navigationBar__items--item > .active > svg > path {
58                            stroke: #000000;
59                        }
60                    </style><link href="https://www.fredrikstadfk.no/om-klubben/bli-medlem" rel="canonical" />
61	<meta name="google-site-verification" content="QYsbnhvcaqFkCtF5H7VI5-Z4pX2BVlcQRWjrhPI9qHU" />
62	<meta name="description" content="Medlemskap i Fredrikstad Fotballklubb styrker tilhørigheten, gir påvirkningsmulighet - og er et bidrag til klubbens økonomi." />
63	<meta property="og:title" content="Bli medlem" />
64	<meta property="og:description" content="Medlemskap i Fredrikstad Fotballklubb styrker tilhørigheten, gir påvirkningsmulighet - og er et bidrag til klubbens økonomi." />
65	<meta property="og:site_name" content="Fredrikstad" />
66	<meta property="og:url" content="https://www.fredrikstadfk.no/om-klubben/bli-medlem" />
67	<meta property="og:type" content="article" />
68	<meta property="og:locale" content="nb_NO" />
69
70	
71		<meta property="og:image" content="https://www.fredrikstadfk.no/_/asset/no.seeds.app.football:0000019ff17deeb0/img/logo/ffk/logo.png" />
72		<meta property="og:image:width" content="1200" />
73		<meta property="og:image:height" content="630" />
74	
75	
76		<meta name="twitter:card" content="summary_large_image" />
77		<meta name="twitter:title" content="Bli medlem" />
78		<meta name="twitter:description" content="Medlemskap i Fredrikstad Fotballklubb styrker tilhørigheten, gir påvirkningsmulighet - og er et bidrag til klubbens økonomi."/>
79		<meta name="twitter:image" content="https://www.fredrikstadfk.no/_/asset/no.seeds.app.football:0000019ff17deeb0/img/logo/ffk/logo.png"/>
80		<meta name="twitter:site" content="fredrikstadfk"/>
81
82
83	<link rel="apple-touch-icon" sizes="57x57" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-57x57.png">
84	<link rel="apple-touch-icon" sizes="60x60" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-60x60.png">
85	<link rel="apple-touch-icon" sizes="72x72" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-72x72.png">
86	<link rel="apple-touch-icon" sizes="76x76" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-76x76.png">
87	<link rel="apple-touch-icon" sizes="114x114" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-114x114.png">
88	<link rel="apple-touch-icon" sizes="120x120" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-120x120.png">
89	<link rel="apple-touch-icon" sizes="144x144" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-144x144.png">
90	<link rel="apple-touch-icon" sizes="152x152" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-152x152.png">
91	<link rel="apple-touch-icon" sizes="180x180" href="/_/asset/no.seeds.app.football/img/logo/ffk/apple-icon-180x180.png">
92	<link rel="icon" type="image/png" sizes="192x192"  href="/_/asset/no.seeds.app.football/img/logo/ffk/android-icon-192x192.png">
93	<link rel="icon" type="image/png" sizes="32x32" href="/_/asset/no.seeds.app.football/img/logo/ffk/favicon-32x32.png">
94	<link rel="icon" type="image/png" sizes="96x96" href="/_/asset/no.seeds.app.football/img/logo/ffk/favicon-96x96.png">
95	<link rel="icon" type="image/png" sizes="16x16" href="/_/asset/no.seeds.app.football/img/logo/ffk/favicon-16x16.png">
96
97
98
99    <meta name="apple-mobile-web-app-status-bar-style" content="#ffffff">
100    <meta name="apple-mobile-web-app-title" content="Fredrikstad">
101    <meta name="apple-mobile-web-app-capable" content="yes">
102
103	<link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/825fd7c1-d52f-45e6-9954-8478775b089e:8e363feadfda68c5f97f160a43b9e16b76ff49da/-1-1/apple-icon-640x1136" media="(device-width: 320px) and (device-height: 568px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/61ca5cb3-654e-4d71-b6e3-1d7d919fc707:dbb173074a6f7e7746fd310772cd96d5a47b9cc3/-1-1/apple-icon-1136x640" media="(device-width: 320px) and (device-height: 568px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/c8aa4044-bf2c-4819-8e0a-1e44edccf3e1:e28e80d2b179242dc002bbc4300878d166394c34/-1-1/apple-icon-750x1334" media="(device-width: 375px) and (device-height: 667px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/c019f748-846b-4eaf-bc0d-9600bc1adf4b:477e39ee03e228338952460e6cf5330392ff2d51/-1-1/apple-icon-1334x750" media="(device-width: 375px) and (device-height: 667px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/5c9ac5e8-c897-4f2a-be3f-e99d8fa81e33:f0327b538c99fe3346a7172258f25a5ee33d2304/-1-1/apple-icon-1242x2208" media="(device-width: 621px) and (device-height: 1104px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/d461d991-b029-4556-a1ee-48a4822e89a0:3984f2f7e7d9523d398d59f003b2c2928b804bf9/-1-1/apple-icon-2208x1242" media="(device-width: 621px) and (device-height: 1104px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/b67a08a4-b30c-4a21-a46b-e1db884267e9:a0053f7d899a667c4965c43cc84bf511a8564666/-1-1/apple-icon-1125x2436" media="(device-width: 375px) and (device-height: 812px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/385110f9-59d3-4150-a894-f48a37c2dcb1:7e6e366bc53162f5ab5b7b93ea78304d00a773c1/-1-1/apple-icon-2436x1125" media="(device-width: 375px) and (device-height: 812px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/6eb48751-e469-4278-9d8b-a8915b94b6f6:16a38c708fc322dc5f9719f6620750f315f349aa/-1-1/apple-icon-828x1792" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/d9593584-34f0-498b-83b0-a44dfb8a5b89:99e0b2d0e8017dc45fc8ff0936c526a865fbd902/-1-1/apple-icon-1792x828" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/a816eed5-1ae5-4a7e-a41c-0befbaf3b979:d24674eb6b18cf36fe29740dcdf73fb0aba5a45a/-1-1/apple-icon-1242x2688" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/9e000cb2-53ef-4610-a270-5
103a80b4e52bbe:6a9607eb1ba3c84c264ce2a7f2aeadba1aa30961/-1-1/apple-icon-2688x1242" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/e8ebdef7-0ab6-4472-8b25-1574a58b3f37:c65f491acd6d8b592a55fcd66b664556a5db7318/-1-1/apple-icon-1536x2048" media="(device-width: 768px) and (device-height: 1024px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/75ebeffc-2172-4b4f-a069-324416c7a0d1:4c88b8def4baab1a9c093959c6e6d16351619088/-1-1/apple-icon-2048x1536" media="(device-width: 768px) and (device-height: 1024px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/5d917b4d-9f10-4005-b0b8-4d3a6eddfcd3:b9449674adfa03e3720c76329e7893e21aedb67a/-1-1/apple-icon-1668x2224" media="(device-width: 834px) and (device-height: 1112px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/31f6b437-5a47-4298-b074-8eb671e5d5c9:eee5e68a7a52c5c4e47131460ec678d7500b73f2/-1-1/apple-icon-2224x1668" media="(device-width: 834px) and (device-height: 1112px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/b3595314-5f29-4993-a03d-78a351d8c7d5:ab1a2285d32225aee769d137e2b2147d67c21903/-1-1/apple-icon-1668x2388" media="(device-width: 834px) and (device-height: 1194px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/36723d97-7291-4c7e-bbdf-d3ff1f62b7e5:13c941288705da7c808db2fb790d405d6c2983b1/-1-1/apple-icon-2388x1668" media="(device-width: 834px) and (device-height: 1194px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/cda4d337-43e4-4b2b-95c8-30840a475d0d:2cfc3da9edd4bdc6840b8dcf22c5475cd7de6db7/-1-1/apple-icon-2048x2732" media="(device-width: 1024px) and (device-height: 1366px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/om-klubben/bli-medlem/_/image/e9fc61a2-94fa-4544-9f68-f792a7176ed9:28d5f2b2d5591e9dc5c78ef8f9c9d0ee85cf367f/-1-1/apple-icon-2732x2048" media="(device-width: 1024px) and (device-height: 1366px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)">
104
105	<meta name="msapplication-TileColor" content="#ffffff">
106	<meta name="msapplication-TileImage" content="/_/asset/no.seeds.app.football/img/logo/ffk/ms-icon-144x144.png">
107	<meta name="theme-color" content="#ffffff">
107<script>window.googletag = window.googletag || {cmd: []};</script>
107<script>
108		googletag.cmd.push(function() {
109			var mapping_common_ad = googletag.sizeMapping().
110			addSize([1300, 0], [[980, 300],[728, 90],[580, 400],[300, 300],[300, 250]]).
111			addSize([1024, 0], [[728, 90],[580, 400],[300, 300],[300, 250]]).
112			addSize([640, 0], [[580, 400],[300, 300],[300, 250]]).
113			addSize([0, 0], [[300, 300],[300, 250]]).
114			build();
115
116			googletag.defineSlot('/64964091/EliteserienFellesArtikkelbunn', [
117				[980, 300], [728, 90], [580, 400], [300, 300], [300, 250]
118			], 'div-gpt-ad-1478554015888-0').
119			defineSizeMapping(mapping_common_ad).
120			addService(googletag.pubads());
121
122			googletag.defineSlot('/317325795/Medieplattform', [[300, 200], [300, 100], [300, 300]], 'div-gpt-ad-1486251995370-0').addService(googletag.pubads());			googletag.pubads().enableSingleRequest();
123			googletag.enableServices();
124		});
125</script>
125<script src="https://cdn.usefathom.com/script.js" data-site="HAZCSTSL"  defer></script>
125<!-- Google Tag Manager -->
125<script>dataLayer = [];</script>
125<script>
vendor: 317 bytes, line 125
125(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src='//www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);})(window,document,'script','dataLayer','
125GTM-K6WX66X2
vendor: 3 bytes, line 125
125');
125</script>
125<!-- End Google Tag Manager --><link rel="alternate" type="application/rss+xml" title="Nyheter" href="https://www.fredrikstadfk.no/rss-nyheter" /></head>
126
127<body data-ng-controller="body" data-ng-class="{'menu-is-visible': showMenu}" class="body__ffk"><!-- Google Tag Manager (noscript) -->
vendor: 61 bytes, line 127
127<noscript><iframe src="//www.googletagmanager.com/ns.html?id=
127GTM-K6WX66X2
vendor: 82 bytes, line 127
127" height="0" width="0" style="display:none;visibility:hidden"></iframe></noscript>
127<!-- End Google Tag Manager (noscript) -->
128
129
130<script>
131    const splashPwa = $('.splash--pwa');
132    const isRunningStandalone = (window.matchMedia('(display-mode: standalone)').matches);
133
134    const shouldShowFakeSplash = sessionStorage.getItem('splash_pwa') !== 'displayed' && isRunningStandalone;
135
136    if (shouldShowFakeSplash){
137        splashPwa.show();
138        $('.splash--pwa img').load(function () {
139            $('.splash--pwa img').show();
140        });
141    }
142
143    document.addEventListener('DOMContentLoaded', onDomLoaded);
144
145    function onDomLoaded(){
146        if (shouldShowFakeSplash){
147            setTimeout(function(){
148                splashPwa.addClass('splash--display--none');
149                sessionStorage.setItem('splash_pwa', 'displayed');
150            }, 3000);
151        }
152    };
153</script>
vendor: 1 bytes, line 153
153
154<script>
155    /*<![CDATA[*/
156    window.fbAsyncInit = function() {
157        FB.init({
158            appId      : false,
159            xfbml      : true,
160            version    : 'v2.8'
161        });
162        FB.AppEvents.logPageView();
163    };
164
165    (function(d, s, id){
166        var js, fjs = d.getElementsByTagName(s)[0];
167        if (d.getElementById(id)) {return;}
168        js = d.createElement(s); js.id = id;
169        js.src =  "\/\/connect.facebook.net\/nb_NO\/sdk.js";
170        fjs.parentNode.insertBefore(js, fjs);
171    }(document, 'script', 'facebook-jssdk'));
172    /*]]>*/
173</script>
173
174
175<svg style="display:none">
176    <symbol id="arrow" viewBox="0 0 46 33">
177        <polygon points="0 18.355 41.662 18.355 41.662 14.355 0 14.355"></polygon>
178        <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359"></polygon>
179    </symbol>
180
181    <symbol id="arrow-right" viewBox="0 0 24 24">
182        <polygon points="7.875,0 4.125,3.75 12.375,12 4.125,20.25 7.875,24 19.875,12 "></polygon>
183    </symbol>
184
185    <symbol id="arrow-left" viewBox="0 0 24 24">
186        <polygon points="16.125,24 19.875,20.25 11.625,12 19.875,3.75 16.125,0 4.125,12 "></polygon>
187    </symbol>
188</svg>
189
190<div class="bg-overflow"></div>
191
192
193    
194        <header class="header" ng-class="{'header--show-menu': showMenu, 'header--show-search': showSearch}">
195	
196	<div class="header__global">
197		<div class="container">
198			<nav class="header__global__nav" aria-label="Meny">
199				<a class="header__global__nav__item" href="https://www.fredrikstadfk.no/flere-ma-fa-mulighet-til-a-ga-pa-kamp">
200					FFK Billettfond
201				</a><a class="header__global__nav__item" href="https://www.fredrikstadfk.no/samfunn">
202					FFK Samfunn
203				</a><a class="header__global__nav__item header__global__nav__item--active" href="https://www.fredrikstadfk.no/om-klubben/bli-medlem">
204					Medlem
205				</a><a class="header__global__nav__item" href="https://ffk-brand-manual.nettpresentasjon.no">
206					Merkevaremanual
207				</a><a class="header__global__nav__item" href="https://ffk-nitten03.no">
208					Nitten03 nettbutikk
209				</a><a class="header__global__nav__item" href="https://www.fredrikstadfk.no/partnere">
210					Partnere
211				</a>
212				<!-- Login/Logout/Minside links -->
213				<input id="idrettens-link-service" type="hidden" value="https://www.fredrikstadfk.no/om-klubben/bli-medlem/_/service/no.seeds.app.football/get-login-links">
214				<a id="login-link" class="modal__login modal-open" href="javascript:void(0)" hidden>
215                    <svg stroke="white" width="24" height="20" viewBox="0 0 24 20" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="loginTitle">
216                        <title id="loginTitle"></title>
217                        <path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke-width="1.5" stroke-miterlimit="10"/>
218                        <path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
219                    </svg>
220                </a>
221                <a id="minside-link" href="javascript:void(0)" hidden>
222                    <svg stroke="white" width="24" height="20" viewBox="0 0 24 20" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="minsideTitle">
223                        <title id="minsideTitle"></title>
224                        <path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke-width="1.5" stroke-miterlimit="10"/>
225                        <path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
226                    </svg>
227                </a>
228                <a id="logout-link" class="logout" href="javascript:void(0)" hidden>
229                    <svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
230 viewBox="0 0 384.971 384.971" style="enable-background:new 0 0 384.971 384.971;" xml:space="preserve" aria-labelledby="logoutTitle">
231                        <title id="logoutTitle"></title>
232                        <g>
233                            <g id="Sign_Out">
234                                <path d="M180.455,360.91H24.061V24.061h156.394c6.641,0,12.03-5.39,12.03-12.03s-5.39-12.03-12.03-12.03H12.03
235                                    C5.39,0.001,0,5.39,0,12.031V372.94c0,6.641,5.39,12.03,12.03,12.03h168.424c6.641,0,12.03-5.39,12.03-12.03
236                                    C192.485,366.299,187.095,360.91,180.455,360.91z"/>
237                                <path d="M381.481,184.088l-83.009-84.2c-4.704-4.752-12.319-4.74-17.011,0c-4.704,4.74-4.704,12.439,0,17.179l62.558,63.46H96.279
238                                    c-6.641,0-12.03,5.438-12.03,12.151c0,6.713,5.39,12.151,12.03,12.151h247.74l-62.558,63.46c-4.704,4.752-4.704,12.439,0,17.179
239                                    c4.704,4.752,12.319,4.752,17.011,0l82.997-84.2C386.113,196.588,386.161,188.756,381.481,184.088z"/>
240                            </g>
241                        </g>
242                    </svg>
243                </a>
244				<a class="open-push-notification-modal header__global__nav__item" href="javascript:void(0)" style="display: none;">
245                    <svg stroke="white" width="24px" height="20px" viewBox="0 0 611.999 611.999" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
246                        <title id="renewPushTitle"></title>
247                        <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
248                            C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
249                            c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
250                            h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
251                            c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
252                            C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
253                            c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
254                            c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
255                            M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
256                            c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
257                            c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"/>
258                        <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
259                            c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
260                            C323.259,126.96,315.532,119.235,306.001,119.235z"/>
261                    </svg>
262                </a>
263			</nav>
264		</div>
265	</div>
266	<div class="header__team">
267		<div class="container">
268			<a href="https://www.fredrikstadfk.no/" class="header__team__brand">
269				<div class="header__team__brand__container">
270					<div class="header__team__brand__div">
271						<img class="header__team__brand__img header__team__brand__img--ffk" src="https://www.fredrikstadfk.no/om-klubben/bli-medlem/_/image/ee43a45b-fbf6-4d1b-8a4a-d7153624a54a:1ce09389606dcc9aa11c4bc63202e24f9fd2c2d9/wide-72-72/FFK-logo-outline2.svg" role="img" alt="Forsiden på fredrikstadfk.no"/>
272					</div>
273					<div class="header__team__brand__titles">
274						<h2 class="header__team__brand__title">Fredrikstad Fotballklubb</h2>
275						<strong class="header__team__brand__tagline">12x Norgesmester - 9x Seriemester</strong>
276					</div>
277				</div>
278			</a>
279		</div>
280	</div>
281	<div class="header__bar">
282		<div class="container">
283			<a class="header__bar__brand" href="https://www.fredrikstadfk.no/">
284				<img class="header__bar__brand__img" src="https://www.fredrikstadfk.no/om-klubben/bli-medlem/_/image/ee43a45b-fbf6-4d1b-8a4a-d7153624a54a:1ce09389606dcc9aa11c4bc63202e24f9fd2c2d9/wide-72-72/FFK-logo-outline2.svg" title="Til forsiden på https://www.fredrikstadfk.no/" alt="Logo" />
285			</a>
286
287			<div class="header__menu">
288				<nav class="header__menu__nav" aria-label="Hovedmeny">
289					<!-- Set modifier class "header__menu__nav__item--active" on active menu elements -->
290					
291						
292							<a class="header__menu__nav__item" href="https://www.fredrikstadfk.no/nyheter">
293								<span class="header__menu__nav__item__title">Nyheter</span>
294							</a>
295						
296					
297					
298						
299							<a class="header__menu__nav__item" href="https://www.fredrikstadfk.no/lag">
300								<span class="header__menu__nav__item__title">VÃ¥re lag</span>
301							</a>
302						
303					
304					
305						
306							<a class="header__menu__nav__item" href="https://www.fredrikstadfk.no/terminl
306iste">
307								<span class="header__menu__nav__item__title">Terminliste</span>
308							</a>
309						
310					
311					
312						
313							<a class="header__menu__nav__item" href="https://www.fredrikstadfk.no/resultater">
314								<span class="header__menu__nav__item__title">Resultater</span>
315							</a>
316						
317					
318					
319						
320							<a class="header__menu__nav__item" href="https://www.fredrikstadfk.no/billettinformasjon">
321								<span class="header__menu__nav__item__title">Billettinfo</span>
322							</a>
323						
324					
325					
326						
327							<a class="header__menu__nav__item" href="https://www.fredrikstadfk.no/om-klubben">
328								<span class="header__menu__nav__item__title">Om FFK</span>
329							</a>
330						
331					
332					
333						
334							<a class="header__menu__nav__item" href="https://www.fredrikstadfk.no/om-stadion">
335								<span class="header__menu__nav__item__title">Fredrikstad Stadion</span>
336							</a>
337						
338					
339					
340				</nav>
341				<div class="header__menu__sponsor">
342					
343
344				</div>
345			</div>
346
347			<div class="header__bar__nav">
348				<button class="header__bar__nav__item header__bar__nav__item--menu" type="button" ng-click="toggleMenu(); showSearch = false;">
349					<span data-ng-if="!showMenu">
350						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
351<path d="M22.4511719,6H1.5C0.671875,6,0,5.3286133,0,4.5S0.671875,3,1.5,3h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
352	S23.2792969,6,22.4511719,6z"></path>
353<path d="M22.4511719,13.5H1.5C0.671875,13.5,0,12.8286133,0,12s0.671875-1.5,1.5-1.5h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
354	S23.2792969,13.5,22.4511719,13.5z"></path>
355<path d="M22.4511719,21H1.5C0.671875,21,0,20.3286133,0,19.5S0.671875,18,1.5,18h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
356	S23.2792969,21,22.4511719,21z"></path>
357</svg></span>
358						Meny
359					</span>
360					<span data-ng-if="showMenu" class="ng-cloak">
361						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
362<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
363	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
364	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
365	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
366	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
367	"></path>
368</svg></span>
369						Lukk meny
370					</span>
371				</button>
372				<button class="header__bar__nav__item header__bar__nav__item--search" type="button" ng-click="toggleSearch(); queryReset = true; showMenu = false;">
373					<span data-ng-if="!showSearch">
374						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
375<path id="search" d="M17.7191334,15.5738506c2.5573559-3.8850498,2.4550629-9.4922314-0.961565-12.9057446
376	c-4.037859-3.754458-10.3484344-3.5178807-14.095067,0.5284102c-3.5613694,3.8462107-3.5484405,9.7972965,0.0296073,13.6279316
377	c3.4166281,3.4135132,8.9916639,3.4852676,12.858386,0.9020691L21.8313618,24L24,21.8268318L17.7191334,15.5738506z
378	 M4.3185873,15.2048225C1.3234186,12.2014732,1.324975,7.3336434,4.3220639,4.3322186s7.854773-2.9998651,10.8499432,0.0034833
379	c2.9938126,3.0019879,2.9938126,7.8671322,0,10.8691206c-2.9951696,3.0033493-7.8528538,3.0049095-10.8499432,0.0034838
380	C4.3209047,15.2071447,4.319746,15.2059841,4.3185873,15.2048225z"></path>
381</svg></span>
382						Søk
383					</span>
384					<span data-ng-if="showSearch" class="ng-cloak">
385						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
386<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
387	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
388	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
389	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
390	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
391	"></path>
392</svg></span>
393						Lukk søk
394					</span>
395				</button>
396			</div>
397		</div>
398		<div class="header__search">
399			<div class="container">
400				<div class="search-field__area o-no-margin">
401					<form action="https://www.fredrikstadfk.no/sok" method="get">
402
403						<input id="search-field__input_header" class="search-field__input" aria-label="Søk" type="text" autocomplete="off" data-ng-model="query"
404						    name="text" data-bind-focus="queryReset" data-ng-focus="queryReset == true" data-e
404sc-key="query = ''" placeholder="Søk i www.fredrikstadfk.no" maxlength="128">
405						
406						<span class="search-field__area__icon" data-ng-show="query.length > 0" data-ng-click="query = ''; queryReset = true;">
407							<span><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
408<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
409	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
410	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
411	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
412	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
413	"></path>
414</svg></span>
415						</span>
416						<span class="search-field__area__icon" data-ng-hide="query.length > 0">
417							<span><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
418<path id="search" d="M17.7191334,15.5738506c2.5573559-3.8850498,2.4550629-9.4922314-0.961565-12.9057446
419	c-4.037859-3.754458-10.3484344-3.5178807-14.095067,0.5284102c-3.5613694,3.8462107-3.5484405,9.7972965,0.0296073,13.6279316
420	c3.4166281,3.4135132,8.9916639,3.4852676,12.858386,0.9020691L21.8313618,24L24,21.8268318L17.7191334,15.5738506z
421	 M4.3185873,15.2048225C1.3234186,12.2014732,1.324975,7.3336434,4.3220639,4.3322186s7.854773-2.9998651,10.8499432,0.0034833
422	c2.9938126,3.0019879,2.9938126,7.8671322,0,10.8691206c-2.9951696,3.0033493-7.8528538,3.0049095-10.8499432,0.0034838
423	C4.3209047,15.2071447,4.319746,15.2059841,4.3185873,15.2048225z"></path>
424</svg></span>
425						</span>
426					</form>
427				</div>
428			</div>
429		</div>
430	</div>
431</header>
432
433    
434    
435
436
437<main class="body  o-no-padding-top o-no-padding-bottom" data-portal-region="main">
438    
439    
440        
441            <article data-portal-component-type="layout" class="article" data-ng-controller="liveDataController as vm" ng-init="vm.setArticleId(&#39;22f89252-7d7b-442f-8994-3b6fe131931d&#39;, &#39;null&#39;)">
442    <header><div class="hero hero--article hero--background-tint">
443
444	
445	
446		
447		<div class="hero__background"></div>
448	
449
450	<div class="hero__content">
451		<div class="container">
452			<div class="heading heading--full">
453				<h1 class="heading__title">
454					<span class="heading__title__typo">Bli medlem</span>
455				</h1>
456			</div>
457		</div>
458	</div>
459</div>
460</header>
461
462    <div class="container">
463        <div class="grid grid--justify-center">
464            <div class="grid__item grid__item-xs-12">
465                <p class="excerpt excerpt--article">Medlemskap i Fredrikstad Fotballklubb styrker tilhørigheten, gir påvirkningsmulighet - og er et bidrag til klubbens økonomi.
466                    
467                </p>
468            </div>
469            <div class="grid__item grid__item-xs-12">
470                <div class="breadcrumbs breadcrumbs--article">
471                    <a href="https://www.fredrikstadfk.no/" class="breadcrumb__link">Forsiden</a>
472                    <span class="breadcrumbs__divider">/</span>
473                    <a href="https://www.fredrikstadfk.no/om-klubben" class="breadcrumb__link">Om Klubben</a>
474                    <span class="breadcrumbs__divider">/</span>
475                </div>
476            </div>
477
478            <!--<div id="refreshBar"></div>-->
479
480            
481<div class="grid__item grid__item-xs-12 grid__item-m-10 grid__item-l-7 ads__grid-item">
482	<div class="box">
483		<div class="ads__grid-div">
484			<div class="ad">
485				<span class="ad__lab">Annonse:</span>
486				<div class="ad__content">
487					<!-- /317325795/Medieplattform -->
488<div id='div-gpt-ad-1486251995370-0'>
489<script>
490googletag.cmd.push(function() { googletag.display('div-gpt-ad-1486251995370-0'); });
491</script>
491
492</div>
493				</div>
494			</div>
495		</div>
496	</div>
497</div>
498
499<div class="grid__item grid__item-xs-12 grid__item-m-10 grid__item-l-7"><div class="box"><p>Registrer deg som medlem <a href="https://fredrikstadfotballklubb.portal.styreweb.com/arrangement/ArrangementSession?ID=Innmelding" target="_blank">her</a>.</p><p>Er du medlem og har registrert deg med e-post, vil du motta faktura for nytt år&nbsp;på denne, eller som eFaktura rett i banken din. Har du ikke registrert din e-post og ikke benytter eFaktura vil fakturaen komme i posten.&nbsp;</p><p>Medlemskort finner du i Gnist-appen etter betaling. Tilgang får man enkelt ved å benytte Vipps-login eller ved å opprette bruker. &nbsp;I Gnist kan du også vedlikeholde egne kontaktopplysninger. Gnist er tilgjengelig på mobil, nettbrett og PC/Mac.</p><p><a data-outlook-id="ab5f2e40-a13b-4d19-84c9-f63ac7e8a0b0" href="https://gnist.styreweb.com/Account/Login?ReturnUrl=/" title="https://gnist.styreweb.com/Account/Login?ReturnUrl=/">Trykk her for å komme i gang med Gnist!</a></p><p>Hovedmedlemskap: 600 kr.<br>Ungdomsmedlemskap (t.o.m. 19 år): 400 kr.<br>Familiemedlemskap (2 voksne, 2 barn): 1000 kr.</p><p><strong>Medlemskap i FFK er en flott måte å støtte klubben på - i tillegg til at du får gode fordeler. Se alle dine fordeler i appen FFK+ eller Gnist.</strong></p><h2>Livstidsmedlemskap</h2><p>Vi får fra tid til annen spørsmål om livstidsmedlemskap. Styret i FFK har vedtatt følgende prising av dette:</p><p>0-40 år = 10.000,-</p><p>41-60 år = 7.500,-</p><p>61 år - = 5.000,-</p></div></div>
500
501
502            
503
504            <div class="grid__item grid__item-xs-12 grid__item-m-10 ads__grid-item">
505                <div class="ad">
506                    <span class="ad__lab">Annonse fra Eliteserien:</span>
507                    <div class="ad__content">
508                        <!-- /64964091/EliteserienFellesArtikkelbunn --><div id='div-gpt-ad-1478554015888-0'>
508<script>googletag.cmd.push(function() { googletag.display('div-gpt-ad-1478554015888-0'); });</script>
508</div>
509                    </div>
510                    
511                    
512                </div>
513            </div>
514
515            <div class="grid__item grid__item-xs-12 grid__item-m-10 grid__item-l-7 article__grid-item">
516                <div class="box o-text-center">
517
518                    <footer>
519                        <small>Publisert: 23.11.2016<span>, oppdatert: 05.08.2026</span>
520                        </small>
521                        <br/>
522                        
523                        <br/>
524                        
525
526                        <div class="share">
527                            <a class="share__target" href="https://twitter.com/intent/tweet?text=https://www.fredrikstadfk.no/om-klubben/bli-medlem"
528                               target="_blank"><?xml version="1.0" encoding="utf-8"?>
529<!-- Generator: Adobe Illustrator 27.7.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
530<svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
531	 viewBox="0 0 49.7 49.7" xml:space="preserve" height="58" width="58">
532<rect y="-0.3" class="st0" width="51" height="51" style="fill:#050304;"/>
533<g id="Layer_2">
534	<path class="st1" style="fill: #FFFFFF;" d="M30.3,22.3L42.5,8.1h-2.9L29,20.4L20.5,8.1h-9.7l12.8,18.6L10.8,41.6h2.9l11.2-13l8.9,13h9.7L30.3,22.3
535		L30.3,22.3z M26.3,26.9L25,25L14.7,10.3h4.4l8.3,11.9l1.3,1.9l10.8,15.5h-4.4L26.3,26.9L26.3,26.9z"/>
536</g>
537</svg></a>
538                            <a class="share__target" href="https://www.facebook.com/sharer.php?u=https://www.fredrikstadfk.no/om-klubben/bli-medlem"
539                               target="_blank"><svg xmlns="http://www.w3.org/2000/svg" width="58" height="58" viewBox="0 0 58 58">
540	<title>share-facebook</title>
541	<polyline points="58 0 58 58 0 58 0 0" style="fill: #050304"></polyline>
542	<path d="M78.441,12.211H72.667V8.662a1.494,1.494,0,0,1,1.6-1.645h4.076V1.153l-5.615-.022c-6.228,0-7.647,4.375-7.647,7.173v3.907h-3.6v6.042h3.6v17.1h7.581v-17.1H77.78Z" transform="translate(-40.648 10.024)" style="fill: #fff"></path>
543</svg></a>
544                        </div>
545                    </footer>
546                </div>
547            </div>
548        </div>
549    </div>
550
551    <div class="container">
552        <div class="grid grid--justify-center">
553	<div class="grid__item grid__item-xs-12 grid__item-m-10 grid__item-l-7">
554		<div id="fb-root"></div>
555		<div class="rm_scr_after">
556
557			
557<script>
558				/*<![CDATA[*/
559				(function(d, s, id) {
560				var js, fjs = d.getElementsByTagName(s)[0];
561				if (d.getElementById(id)) return;
562				js = d.createElement(s); js.id = id;
563				js.src = "\/\/connect.facebook.net\/nb_NO\/sdk.js#xfbml=1\u0026version=v2.8";
564				fjs.parentNode.insertBefore(js, fjs);
565			}(document, 'script', 'facebook-jssdk'));
566
567				/*]]>*/
568			</script>
568
569		</div>
570		<div class="fb-like" data-layout="button_count" data-action="like" data-size="small" data-show-faces="true" data-share="false" data-href="https://www.fredrikstadfk.no/om-klubben/bli-medlem"></div>
571		<div class="fb-comments" data-numposts="10" data-width="100%" data-href="https://www.fredrikstadfk.no/om-klubben/bli-medlem"></div>
572	</div>
573</div>
574
575    </div>
576    <div role="region" data-portal-region="plugins">
577        
578    </div>
579</article>
580
581
582            
583        
584    
585    
586</main>
587
588
589    <div class="navigationBarWrapper">
590	<div class="navigationBar">
591		<div class="navigationBar__items">
592			<div class="navigationBar__items--item">
593				<a class="icon" href="/">
594					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
595						<path d="M14.2495 14.25H9.74945V20.2493L3.75 20.2499V10.5L12 3L20.25 10.5V20.2499L14.2495 20.2493V14.25Z" stroke="white" stroke-width="1.5" stroke-linecap="round"/>
596					</svg>
597				</a>
598			</div>
599			<div class="navigationBar__items--item">
600				<button class="icon" data-itemNav="search">
601					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
602						<path d="M10.875 18.75C15.2242 18.75 18.75 15.2242 18.75 10.875C18.75 6.52576 15.2242 3 10.875 3C6.52576 3 3 6.52576 3 10.875C3 15.2242 6.52576 18.75 10.875 18.75Z" stroke="white" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
603						<path d="M16.4431 16.4438L20.9994 21.0001" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
604					</svg>
605				</button>
606			</div>
607			<div class="navigationBar__items--item">
608				<a class="icon" href="https://fantasy.eliteserien.no/" target="_blank">
609					<img src="/_/image/ec517e8f-7cc4-48ed-bd0e-800e8b643e2b:d3b5fb4e2ce0059858ae8949a2ba48f3d401011f/block-24-24/fantasy-logo_white_responsive.svg" />
610				</a>
611			</div>
612			<div class="navigationBar__items--item" hidden>
613				<button class="icon" data-itemNav="user">
614					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
615						<path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke="white" stroke-width="1.5" stroke-miterlimit="10"/>
616						<path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
617					</svg>
618				</button>
619			</div>
620			<div class="navigationBar__items--item">
621				<button class="icon" data-itemNav="menu">
622					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
623						<path d="M3.75 12H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
624						<path d="M3.75 6H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
625						<path d="M3.75 18H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
626					</svg>
627				</button>
628			</div>
629		</div>
630	</div>
631</div>
632
633<div class="navigationContentWrapper" data-itemNav="search" aria-expanded="false">
634
635	<div class="navigationArea"></div>
636	<div class="navigationBtnSwipe"></div>
637
638	<div class="navigationContent">
639
640		<div class="inputSearch">
641            <form action="https://www.fredrikstadfk.no/sok" method="get">
642                <input type="text" name="text" id="sok-mobile-input" maxlength="128">
643                
644                <button aria-label="Søk">
645                    <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" aria-hidden="true">
646                        <path d="M10.875 18.75C15.2242 18.75 18.75 15.2242 18.75 10.875C18.75 6.52576 15.2242 3 10.875 3C6.52576 3 3 6.52576 3 10.875C3 15.2242 6.52576 18.75 10.875 18.75Z" stroke="white" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
647                        <path d="M16.4431 16.4438L20.9994 21.0001" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
648                    </svg>
649                </button>
650            </form>
651        </div>
652
653		<div class="popularSearch">
654			<h3>Populære søk</h3>
655			<div class="popularSearch__list">
656				<a href="/sok?text=Billetter" class="item">
657                    Billetter
658                </a><a href="/sok?text=Lagoppstilling" class="item">
659                    Lagoppstilling
660                </a>
661			</div>
662		</div>
663
664	</div>
665</div>
666
667<div class="navigationContentWrapper" data-itemNav="user" aria-expanded="false" data-service-url="/_/service/no.seeds.app.football/get-idrettens-details">
668
669    <div class="navigationArea"></div>
670	<div class="navigationBtnSwipe"></div>
671
672	<div class="navigationContent">
673		<div class="ui loader"></div>
674		<div class="loginTab loginButton" hidden>
675			<div class="loginTab__header--content">
676				<p id="loginMessage" class="login-description"></p>
677				<a class="modal-open" href="javascript:void(0)"></a>
678			</div>
679		</div>
680        <div class="loginTab userDetails" hidden>
681            <div class="navigationButtons">
682                <a href="https://www.fredrikstadfk.no/minside" class="button active">PROFIL</a>
683                <a href="https://www.fredrikstadfk.no/minside?ticket=true" class="button">BILLETTER</a>
684                <a href="https://www.fredrikstadfk.no/minside?edit=true" class="button">REDIGER PROFIL</a>
685             </div>
686            <div class="loginTab__header">
687                <div class="loginTab__header--image">
688					<div class="ntfpwa__default__profile__small"></div>
689                </div>
690                <div class="loginTab__header--content">
691                    <span name="completename"></span>
692                </div>
693				<div class="loginTab__header--notification renew-push-notifications" style="display: none;">
694					<svg stroke="white" width="32px" height="64px" viewBox="0 0 611.999 611.999" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
695						<title id="renewPushTitle"></title>
696						<path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
697							C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
698							c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
699							h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
700							c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
701							C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
702							c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
703							c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
704							M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
705							c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
706							c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"></path>
707						<path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
708							c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
709							C323.259,126.96,315.532,119.235,306.001,119.235z"></path>
710					</svg>
711					<div class="notification-loading">
712						<img src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/img/loading.gif" />
713					</div>
714				</div>
715            </div>
716
717            <div class="loginTab__content">
718                <dl class="loginTab__content--info">
719					<dt>EPost</dt>
720                    <dd name="email"></dd>
721					<dt>Mobilnummer</dt>
722					<dd name="phone"></dd>
723					<dt>Fødselsdato</dt>
724					<dd name="birthdate"></dd>
725					<dt>Adresse</dt>
726					<dd name="address"></dd>
727					<dt>Postnr.</dt>
728					<dd name="zipcode"></dd>
729					<dt>Poststed</dt>
730					<dd name="city"></dd>
731					<dt>Kjønn</dt>
732					<dd name="sex"></dd>
733                </dl>
734
735                <h4>Pushmeldinger</h4>
736
737                <dl class="loginTab__content--options notification-tab">
738                    <dt>Generelle varslinger</dt>
739                    <dd name="general-alert">
740                        <div class="switch__container">
741                            <input id="notification-general-alert-from-bottom" data-id="notification-general-alert" class="switch switch--shadow" type="checkbox" disabled />
742                            <label for="notification-general-alert-from-bottom"></label>
743                        </div>
744                    </dd>
745                    <dt>Varsling ved publisering av nyheter</dt>
746                    <dd name="news">
747                        <div class="switch__container">
748                            <input id="notification-news-from-bottom" data-id="notification-news" class="switch switch--shadow" type="checkbox" disabled />
749                            <label for="notification-news-from-bottom"></label>
750                        </div>
751                    </dd>
752                    <dt>Kamphendelser</dt>
753                    <dd name="match">
754                        <div class="switch__container">
755                            <input id="notification-match-from-bottom" data-id="notification-match" class="switch switch--shadow" type="checkbox" disabled />
756                            <label for="notification-match-from-bottom"></label>
757                        </div>
758                    </dd>
759                </dl>
760
761                <h4>Kommunikasjon og Samtykker</h4>
762
763                <dl class="loginTab__content--options">
764					
765						<dt>SMS</dt>
766						<dd name="1001">
767							<div class="switch__container">
768								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
769								<label for="switch-shadow"></label>
770							</div>
771						</dd>
772					
773						<dt>Epost</dt>
774						<dd name="1002">
775							<div class="switch__container">
776								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
777								<label for="switch-shadow"></label>
778							</div>
779						</dd>
780					
781						<dt>Kommunikasjon fra våre partnere</dt>
782						<dd name="1004">
783							<div class="switch__container">
784								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
785								<label for="switch-shadow"></label>
786							</div>
787						</dd>
788					
789						<dt>Kommunikasjon fra OBOS-ligaen og Eliteserien</dt>
790						<dd name="1005">
791							<div class="switch__container">
792								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
793								<label for="switch-shadow"></label>
794							</div>
795						</dd>
796					
797						<dt>Kommunikasjon fra rettighetshaver</dt>
798						<dd name="1006">
799							<div class="switch__container">
800								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
801								<label for="switch-shadow"></label>
802							</div>
803						</dd>
804					
805                </dl>
806            </div>
807			<div class="navigationButtons">
808                <a href="" class="button">REDIGER SAMTYKKER</a>
809             </div>
810        </div>
811	</div>
812</div>
813
814<div class="navigationContentWrapper" data-itemNav="menu" aria-expanded="false">
815
816    <div class="navigationArea"></div>
817	<div class="navigationBtnSwipe"></div>
818
819	<div class="navigationContent">
820		
821
822		<div class="groupLink">
823			<a class="item" href="https://www.fredrikstadfk.no/nyheter">
824                Nyheter
825                
826				
827				
828				
829            </a><a class="item" href="https://www.fredrikstadfk.no/lag">
830                VÃ¥re lag
831                
832				
833				
834				
835            </a>
835<a class="item" href="https://www.fredrikstadfk.no/terminliste">
836                Terminliste
837                
838				
839				
840				
841            </a><a class="item" href="https://www.fredrikstadfk.no/resultater">
842                Resultater
843                
844				
845				
846				
847            </a><a class="item" href="https://www.fredrikstadfk.no/billettinformasjon">
848                Billettinfo
849                
850				
851				
852				
853            </a><a class="item" href="https://www.fredrikstadfk.no/om-klubben">
854                Om FFK
855                
856				
857				
858				
859            </a><a class="item" href="https://www.fredrikstadfk.no/om-stadion">
860                Fredrikstad Stadion
861                
862				
863				
864				
865            </a>
866		</div>
867
868		<div class="groupLink">
869			
870				<a class="item" href="https://www.fredrikstadfk.no/flere-ma-fa-mulighet-til-a-ga-pa-kamp">
871					FFK Billettfond
872					
873				</a>
874			
875				<a class="item" href="https://www.fredrikstadfk.no/samfunn">
876					FFK Samfunn
877					
878				</a>
879			
880				<a class="item" href="https://www.fredrikstadfk.no/om-klubben/bli-medlem">
881					Medlem
882					
883				</a>
884			
885				<a class="item" href="https://ffk-brand-manual.nettpresentasjon.no" target="_blank">
886					Merkevaremanual
887					<span>
888						<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
889							<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
890						</svg>
891					</span>
892				</a>
893			
894				<a class="item" href="https://ffk-nitten03.no" target="_blank">
895					Nitten03 nettbutikk
896					<span>
897						<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
898							<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
899						</svg>
900					</span>
901				</a>
902			
903				<a class="item" href="https://www.fredrikstadfk.no/partnere" target="_blank">
904					Partnere
905					<span>
906						<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
907							<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
908						</svg>
909					</span>
910				</a>
911			
912		</div>
913
914		<div class="groupLink">
915			<a class="item open-push-notification-modal" href="javascript:void(0)" style="display: none;">
916				PUSH-VARSLINGER
917				<span>
918					<svg stroke="white" width="24px" height="20px" viewBox="0 0 611.999 611.999" fill="#010101" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
919                        <title id="renewPushTitle"></title>
920                        <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
921                            C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
922                            c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
923                            h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
924                            c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
925                            C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
926                            c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
927                            c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
928                            M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
929                            c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
930                            c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"/>
931                        <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
932                            c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
933                            C323.259,126.96,315.532,119.235,306.001,119.235z"/>
934                    </svg>
935				</span>
936			</a>
937		</div>
938	</div>
939
940</div>
941
942
943    <footer class="footer">
944	<div class="footer__bar">
945		<a class="footer__bar__brand" href="/" >
946			<img class="footer__bar__brand__img" src="https://www.fredrikstadfk.no/om-klubben/bli-medlem/_/image/ee43a45b-fbf6-4d1b-8a4a-d7153624a54a:1ce09389606dcc9aa11c4bc63202e24f9fd2c2d9/wide-72-72/FFK-logo-outline2.svg" alt="Klubb"/>
947		</a>
948	</div>
949	<div class="footer__content">
950		<div class="container">
951			<p>
952			<span class="footer__contact">
953				<span>E-post</span>:
954				<a href="/cdn-cgi/l/email-protection#d6bfb8b0b996b0a4b3b2a4bfbda5a2b7b2b0bdf8b8b9"><span class="__cf_email__" data-cfemail="ddb4b3bbb29dbbafb8b9afb4b6aea9bcb9bbb6f3b3b2">[email&#160;protected]</span></a>
955			</span>
956			
957			
958			<span class="footer__contact">
959				<a href="https://www.fredrikstadfk.no/om-klubben">Kontakt oss</a>
960			</span>
961			</p>
962			<div class="o-space-grid-gutter"></div>
963			<p>
964			<span class="footer__contact">
965				<a target="_blank" class="link link--with-icon" href="https://www.facebook.com/fredrikstadfk">
966					<span class="link__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
967<g>
968	<path d="M12,0C5.3725586,0,0,5.3725586,0,12s5.3725586,12,12,12s12-5.3725586,12-12S18.6274414,0,12,0z M14.5249634,12.3076782
969		h-1.6512451c0,2.6392212,0,5.8892212,0,5.8892212h-2.4484863c0,0,0-3.2174683,0-5.8892212H9.2615356v-2.0810547h1.1636963
970		V8.8809204c0-0.9638672,0.4581909-2.4708252,2.4697266-2.4708252l1.8133545,0.0076294V8.437439c0,0-1.1022949,0-1.3163452,0
971		c-0.2142944,0-0.5182495,0.1066895-0.5182495,0.5664673v1.2227173h1.8647461L14.5249634,12.3076782z"></path>
972</g>
973</svg></span>
974					FFK på Facebook
975				</a>
976			</span><span class="footer__contact">
977				<a target="_blank" class="link link--with-icon" href="https://www.instagram.com/fredrikstadfotballklubb/">
978					<span class="link__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
979<g>
980	<path d="M12,0C5.3725586,0,0,5.3725586,0,12s5.3725586,12,12,12s12-5.3725586,12-12S18.6274414,0,12,0z M14.5249634,12.3076782
981		h-1.6512451c0,2.6392212,0,5.8892212,0,5.8892212h-2.4484863c0,0,0-3.2174683,0-5.8892212H9.2615356v-2.0810547h1.1636963
982		V8.8809204c0-0.9638672,0.4581909-2.4708252,2.4697266-2.4708252l1.8133545,0.0076294V8.437439c0,0-1.1022949,0-1.3163452,0
983		c-0.2142944,0-0.5182495,0.1066895-0.5182495,0.5664673v1.2227173h1.8647461L14.5249634,12.3076782z"></path>
984</g>
985</svg></span>
986					FFK på Instagram
987				</a>
988			</span><span class="footer__contact">
989				<a target="_blank" class="link link--with-icon" href="https://twitter.com/fredrikstadfk">
990					<span class="link__icon"><svg version="1.1" id="svg5" xmlns:svg="http://www.w3.org/2000/svg"
991	 xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 1668.56 1221.19"
992	 style="enable-background:new 0 0 1668.56 1221.19;" xml:space="preserve">
993<circle cx="834.28" cy="610.595" r="800" fill="white"/>
994<g id="layer1" transform="translate(52.390088,-25.058597)">
995	<path id="path1009" d="M283.94,167.31l386.39,516.64L281.5,1104h87.51l340.42-367.76L984.48,1104h297.8L874.15,558.3l361.92-390.99
996		h-87.51l-313.51,338.7l-253.31-338.7H283.94z M412.63,231.77h136.81l604.13,807.76h-136.81L412.63,231.77z" fill="black"/>
997</g>
998</svg>
999</span>
1000					FFK på Twitter
1001				</a>
1002			</span>
1003			</p>
1004			<div class="o-space-gutter-3"></div>
1005			<form class="newsletter ng-pristine ng-scope ng-valid-email ng-invalid ng-invalid-required" data-ng-controller="newsletter" name="formNewsletter" data-custom-submit="submitForm(input)" novalidate="novalidate">
1006				<div data-ng-hide="formNewsletter.formNewsletterEmail.$valid &amp;&amp; !formNewsletter.formNewsletterEmail.$errors &amp;&amp; submitted">
1007					<label class="label" for="formNewsletterEmail">Abonner på nyhetsbrev fra Fredrikstad</label>
1008					<div class="newsletter__input">
1009						<div class="form__block">
1010							<input class="input ng-pristine ng-untouched ng-empty ng-valid-email ng-invalid ng-invalid-required" name="formNewsletterEmail" id="formNewsletterEmail" aria-describedby="formNewsletterEmailError" type="email" value="" data-ng-model="input.formNewsletterEmailValidation" required="" placeholder="E-postadresse" />
1011							<!-- ngIf: formNewsletter.formNewsletterEmail.$invalid && submitted -->
1012						</div>
1013					</div>
1014					<div class="newsletter__submit">
1015						<button class="button button--full" type="submit">PÃ¥melding</button>
1016					</div>
1017				</div>
1018				<div class="newsletter__success ng-hide" data-ng-show="formNewsletter.formNewsletterEmail.$valid &amp;&amp; !formNewsletter.formNewsletterEmail.$errors &amp;&amp; submitted">
1019					<div class="box" ng-cloak="">
1020						<p ng-bind="newsletterResponse" class="o-color-ffk-safe-dark">
1021							Takk for din påmelding!
1022						</p>
1023					</div>
1024				</div>
1025			</form>
1026			<p>Dette er Fredrikstad Fotballklubbs offisielle hjemmeside. <br>Bruk av materiale fra våre sider kan ikke skje uten avtale. <br>Ansvarlig redaktør er Markus Slyngenborg Jensen.</p>
1027
1028			<p>
1029				<a href="https://www.eliteserien.no/vilkar-og-betingelser" target="_blank">Vilkår og betingelser</a>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="https://www.eliteserien.no/personvern" target="_blank">Personvern</a>
1030			</p>
1031		</div>
1032	</div>
1033</footer>
1034
1035
1036
1037<div class="modal-login">
1038    <a href="javascript:void(0)" title="Close" class="modal-login__close">X</a>
1039    <div class="modal-login__title">
1040        <h2>Innlogging på Fredrikstad</h2>
1041    </div>
1042    <div class="modal-login__content">
1043        <p><p>PÃ¥ denne nettsiden benyttes Idrettens ID til innlogging. Idrettens ID er en enkel og trygg innlogging utviklet av Norges idrettsforbund og Buypass. Les mer om Idrettens ID hos <a href="https://www.idrettsforbundet.no/digital/idrettens-id/">Norges Idrettsforbund</a></p>
1044
1045<h2>Jeg har bruker</h2>
1046
1047<p>Hvis du allerede har en bruker: <a href="/_/idprovider/idrettensid/login?idProvider=idrettensid">logg inn her</a></p>
1048
1049<h2>Jeg må lage ny bruker</h2>
1050
1051<p>Ny bruker kan du lage <a href="https://signup.nif.no/" target="_blank">her</a></p>
1052
1053<p><strong>PS: </strong>Hvis du er usikker på om du har en bruker kan du finne ut av det <a href="https://www.nif.buypass.no/nif-forgot-password/">hos Norges idrettsforund.</a></p>
1054</p>
1055    </div>
1056</div>
1057
1058<div class="modal-notification">
1059    <a href="javascript:void(0)" title="Close" class="modal-notification__close">X</a>
1060    <div class="modal-notification__title">
1061        <h2>Header</h2>
1062    </div>
1063    <div class="modal-notification__content">
1064        <p>Content</p>
1065    </div>
1066</div>
1067
1068<div class="modal-notification-switch">
1069    <a href="javascript:void(0)" title="Close" class="modal-notification-switch__close">X</a>
1070    <div class="modal-notification-switch__title">
1071        <h2>
1072            <svg stroke="#010101" width="24px" height="24px" viewBox="0 0 611.999 611.999" fill="#010101" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
1073                <title id="renewPushTitle"></title>
1074                <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
1075                    C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
1076                    c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
1077                    h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
1078                    c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
1079                    C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
1080                    c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
1081                    c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
1082                    M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
1083                    c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
1084                    c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"></path>
1085                <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
1086                    c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
1087                    C323.259,126.96,315.532,119.235,306.001,119.235z"></path>
1088            </svg>
1089            <span>Header</span>
1090        </h2>
1091    </div>
1092    <div class="modal-notification-switch__content">
1093        <p>Content</p>
1094    </div>
1095    <div class="switch__container">
1096        <input id="modal-notification-switch" class="switch switch--shadow" type="checkbox" />
1097        <label for="modal-notification-switch"></label>
1098        <div class="modal-notification-loading">
1099            <img src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/img/loading.gif" />
1100        </div>
1101    </div>
1102</div>
vendor: 110 bytes, lines 1102-1104
1102
1103
1104<script data-cfasync="false" src="/cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script>
1104<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/compiled/js/app.bundle.js"></script>
vendor: 1 bytes, line 1104
1104
1105<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/js/blazy.js" defer></script>
vendor: 1 bytes, line 1105
1105
1106<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/js/navigation-bar.js"></script>
vendor: 1 bytes, line 1106
1106
1107<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/js/embed-league-table.js"></script>
1107
1108
1109
1110
1111
1112
1113<script type="text/javascript" src="/_/asset/ntfpwa:0000019dab7c0930/bundles/js/sw/register.js"></script>
vendor: 1 bytes, line 1113
1113
1114<script type="text/javascript">
1115    Starter.registerServiceWorker('https://www.fredrikstadfk.no/')
1116</script>
1116
1117<!-- Firebase SW -->
1118<script src="https://www.gstatic.com/firebasejs/10.9.0/firebase-app-compat.js"></script>
vendor: 1 bytes, line 1118
1118
1119<script src="https://www.gstatic.com/firebasejs/10.9.0/firebase-messaging-compat.js"></script>
vendor: 1 bytes, line 1119
1119
1120<script type="text/javascript" src="/_/asset/ntfpwa:0000019dab7c0930/bundles/js/push-notification.js" data-service-connect-url="https://www.fredrikstadfk.no/om-klubben/bli-medlem/_/service/no.seeds.app.football/push-notification-connect" data-service-manage-notifications-url="https://www.fredrikstadfk.no/om-klubben/bli-medlem/_/service/no.seeds.app.football/push-notification-manage" data-api-key="AIzaSyBG6ZX1FtMCafepTSIgPa46BT35hUqTg3w" data-auth-domain="ntf-pwa.firebaseapp.com" data-project-id="ntf-pwa" data-storage-bucket="ntf-pwa.appspot.com" data-messaging-sender-id="153894812237" data-app-id="1:153894812237:web:e2034b52443c51136c7a04" data-vapid-key="BIjKkVgFdPrJ1KnET80h3CeKFJnOPk9QiQo8qZli_fiQUa1WFqn9va9QgTKZeybEr_d6GA3uxqYnRmwlHkpi7dU" data-icon-url="/_/service/no.seeds.app.football/asset/0000019ff17deeb0/img/logo/ffk/android-icon-512x512.png" data-email-domain="fredrikstadfk.no" data-is-loged="false">
1121</script>
1121
1122<!-- Firebase SW end -->
1123
1124<script>
1125    var isAlreadyLoggedIdrettens = localStorage.getItem('isAlreadyLoggedIdrettens') || false;
1126    if (isAlreadyLoggedIdrettens) {
1127        localStorage.setItem('isAlreadyLoggedIdrettens', true);
1128    }
1129</script>
1129
1130
1131<script type="module" src="https://static.cloudflareinsights.com/beacon.min.js/v31edd6df95cf4e85bb4c19e7a9bdbcba1788362987495" integrity="sha512-iIg7k2xntmwu6/uSb5tpc/hySgZc4eoL31yB29W6tJFo2akwjPWcEqnCEdJvGexCL0KEQwVYv5BlowfhVz26hg==" data-cf-beacon='{"version":"2024.11.0","token":"f4583f8416bf49ae81778bd2491d8277","r":1,"spa":2}' crossorigin="anonymous"></script>
1131
1132</body>
1133</html>

Line numbers count LF bytes from the start of the resource, as the search results do. Vendor segments are library code the classifier recognised; they are stored but not indexed. Bytes are shown as Latin1 characters, one per byte.